@@ -2,6 +2,7 @@ from . import mon  # noqa
 from .install import install, mirror_install, repo_install, repository_url_part, rpm_dist  # noqa
 from .uninstall import uninstall  # noqa
 from ceph_deploy.util import pkg_managers
+from ceph_deploy.util.system import is_systemd
 
 # Allow to set some information about this distro
 #
@@ -21,9 +22,12 @@ def choose_init(module):
     if module.normalized_release.int_major < 7:
         return 'sysvinit'
 
-    if not module.conn.remote_module.path_exists("/usr/lib/systemd"):
+    if not module.conn.remote_module.path_exists("/usr/lib/systemd/system/ceph.target"):
         return 'sysvinit'
 
+    if is_systemd(module.conn):
+        return 'systemd'
+
     return 'systemd'
 
 def get_packager(module):
