@@ -174,6 +174,7 @@ def install(args):
                 args.adjust_repos,
                 components=components,
                 gpgcheck=gpgcheck,
+                args=args
             )
 
         # Detect and install custom repos here if needed
@@ -189,6 +190,7 @@ def install(args):
                 args.adjust_repos,
                 components=components,
                 gpgcheck = gpgcheck,
+                args=args
             )
 
         # Check the ceph version we just installed
@@ -468,12 +470,12 @@ def make(parser):
         help='install a bleeding edge build from Git branch\
                 or tag (default: %(default)s)',
     )
-    version.add_argument(
+    parser.add_argument(
         '--dev-commit',
         nargs='?',
         action=StoreVersion,
         metavar='COMMIT',
-        help='install a bleeding edge build from Git commit',
+        help='install a bleeding edge build from Git commit (defaults to master branch)',
     )
 
     version.set_defaults(
