@@ -1,7 +1,3 @@
-try:
-    from cStringIO import StringIO
-except ImportError:
-    from io import StringIO
 import errno
 import logging
 import os
@@ -141,7 +137,7 @@ def create_rgw(distro, name, cluster, init):
 
 
 def rgw_create(args):
-    cfg = conf.ceph.load(args)
+    conf_data = conf.ceph.load_raw(args)
     LOG.debug(
         'Deploying rgw, cluster %s hosts %s',
         args.cluster,
@@ -167,11 +163,9 @@ def rgw_create(args):
             if hostname not in bootstrapped:
                 bootstrapped.add(hostname)
                 LOG.debug('deploying rgw bootstrap to %s', hostname)
-                conf_data = StringIO()
-                cfg.write(conf_data)
                 distro.conn.remote_module.write_conf(
                     args.cluster,
-                    conf_data.getvalue(),
+                    conf_data,
                     args.overwrite_conf,
                 )
 
